#import <Foundation/Foundation.h>

#if !TARGET_OS_IPHONE

#import <AppKit/AppKit.h>
#import <Carbon/Carbon.h>

@interface NSColor (PCAdditions)

- (NSColor*)pc_colorByAdjustingBrightness:(CGFloat)brightnessDelta;
- (NSColor*)pc_colorByAdjustingBrightness:(CGFloat)brightnessDelta minimum:(CGFloat)minimum;
- (NSColor*)pc_colorByAdjustingBrightnessByPercentage:(CGFloat)brightnessDelta;
- (NSColor*)pc_colorWithBrightness:(CGFloat)brightness;

- (NSColor*)pc_colorByAdjustingSaturation:(CGFloat)saturationDelta;
- (NSColor*)pc_colorByAdjustingSaturation:(CGFloat)saturationDelta minimum:(CGFloat)minimum;
- (NSColor*)pc_colorByAdjustingSaturationByPercentage:(CGFloat)saturationDelta;

- (NSColor*)pc_colorByAdjustingHue:(CGFloat)hueDelta;
- (NSColor*)pc_colorByAdjustingHue:(CGFloat)hueDelta minimum:(CGFloat)minimum;

- (CGColorRef)pc_CGColor;
- (NSColor*)pc_graphiteFromAqua;
+ (NSControlTint)pc_currentControlTint;
+ (NSColor*)pc_colorWithCGColor:(CGColorRef)colorRef;
+ (NSColor*)pc_colorWithThemeBrush:(ThemeBrush)themeBrush;
+ (NSColor*)pc_colorWithThemeTextColor:(ThemeTextColor)themeTextColor;
+ (NSColor*)pc_linenColor;
+ (NSColor*)pc_checkerboardColor;
+ (NSColor*)pc_calibratedRGBColorWithValues:(const CGFloat*)values;
+ (NSColor*)pc_controlTintColor;
- (NSColor*)pc_inverseColor;

- (BOOL)pc_isDarkColor;
- (BOOL)pc_isGrayscaleColor;
- (NSColor*)pc_dividerLineColor;
- (NSColor*)pc_placardViewColor;

+ (NSColor*)pc_colorWithHue:(CGFloat)hue saturation:(CGFloat)saturation lightness:(CGFloat)lightness alpha:(CGFloat)alpha;
- (void)pc_getHue:(CGFloat*)hue saturation:(CGFloat*)saturation lightness:(CGFloat*)lightness alpha:(CGFloat*)alpha;
- (NSColor*)pc_colorByAdjustingLightness:(CGFloat)lightness;
- (NSColor*)pc_colorByAdjustingLightness:(CGFloat)lightness minimum:(CGFloat)minimum;
- (NSColor*)pc_colorByAdjustingLightnessByPercentage:(CGFloat)delta;

+ (NSColor*)pc_labelColor; // yosemite labelColor, returns nil if not available
+ (NSColor*)pc_secondaryLabelColor; // yosemite secondaryLabelColor, returns nil if not available
+ (NSColor*)pc_windowBackgroundColor; // returns hard coded window background color, use for converting

// LAB Colors

- (NSColor*)pc_labColor;
- (NSColor*)pc_colorByAdjustingLuminance:(CGFloat)luminance;
- (NSColor*)pc_colorByAdjustingLuminance:(CGFloat)luminance saturation:(CGFloat)saturation;
- (CGFloat)pc_deltaEWithColor:(NSColor*)aColor;

@end


@interface NSColorSpace (LAB)

+ (NSColorSpace *)pc_labColorSpace;

@end

#else

#import <UIKit/UIKit.h>

@interface UIColor (PCAdditions)

- (UIColor*)pc_colorByAdjustingBrightness:(CGFloat)brightnessDelta;
- (UIColor*)pc_colorByAdjustingBrightness:(CGFloat)brightnessDelta minimum:(CGFloat)minimum;

- (UIColor*)pc_colorByAdjustingSaturation:(CGFloat)saturationDelta;
- (UIColor*)pc_colorByAdjustingSaturation:(CGFloat)saturationDelta minimum:(CGFloat)minimum;

- (UIColor*)pc_colorByAdjustingLightness:(CGFloat)lightness;
- (UIColor*)pc_colorByAdjustingLightness:(CGFloat)lightness minimum:(CGFloat)minimum;

+ (UIColor*)pc_colorWithHue:(CGFloat)hue saturation:(CGFloat)saturation lightness:(CGFloat)lightness alpha:(CGFloat)alpha;
- (UIColor*)pc_colorByAdjustingHue:(CGFloat)delta minimum:(CGFloat)minimum;
- (void)pc_getHue:(CGFloat*)hue saturation:(CGFloat*)saturation lightness:(CGFloat*)lightness alpha:(CGFloat*)alpha;

@end

#endif