#import <AppKit/AppKit.h>

extern void FreeImageRefData(void* info, const void* data, size_t size);

@interface NSImage (PCAdditions)

// creation methods

- (CGImageRef)pc_CGImage;
- (CGImageRef)pc_CGImageWithPixelSize:(NSSize)pixelSize;
- (NSBitmapImageRep*)pc_bitmapImageRep;
- (CIImage*)pc_CIImage;
- (CGLayerRef)pc_CGLayer;
- (CGLayerRef)pc_CGLayerWithAlpha:(CGFloat)alpha;
+ (NSImage*)pc_imageWithCIImage:(CIImage*)image;
+ (NSImage*)pc_imageWithCGImage:(CGImageRef)cgimage;

// general methods

+ (NSImage*)pc_dragImageWithBadgeForCount:(NSUInteger)count baseImage:(NSImage*)baseImage offset:(NSPointPointer)dragImageOffset; // constructs a red-badged custom drag image for multi-item drags or nil if a badged image is inappropriate for the requested count

+ (NSImage*)pc_templateImageNamed:(NSString*)name;
+ (NSImage*)pc_templateImageNamed:(NSString*)name size:(NSSize)size;

- (void)pc_setTemplateIfSupported;
- (NSImage*)pc_whiteTemplateImage;
- (NSImage*)pc_blueTemplateImage;
- (NSImage*)pc_templateImageWithGradient:(NSGradient*)fillGradient glow:(BOOL)glow;
- (NSImage*)pc_templateImageWithGradient:(NSGradient*)fillGradient glow:(BOOL)glow shadow:(BOOL)shadow;

+ (NSImage*)pc_resultsImageForCount:(NSUInteger)count backgroundColor:(NSColor*)backgroundColor foregroundColor:(NSColor*)foregroundColor;
+ (NSImage*)pc_resultsImageWithString:(NSString*)inString backgroundColor:(NSColor*)backgroundColor foregroundColor:(NSColor*)foregroundColor font:(NSFont*)font;
+ (NSImage*)pc_systemIcon:(OSType)type withSize:(NSSize)size;

- (NSImage*)pc_imageByScalingProportionallyDownToSize:(NSSize)newSize; // won't scale images up, pads borders around new image to fit into newSize
- (NSImage*)pc_imageByScalingProportionallyToSize:(NSSize)newSize canUpscale:(BOOL)upscale; // scales images to either the width or height of newSize depending on proportions
- (NSImage*)pc_copyWithSize:(NSSize)size usingInterpolation:(NSImageInterpolation)interpolation NS_RETURNS_RETAINED;
- (NSImage*)pc_copyWithSize:(NSSize)size NS_RETURNS_RETAINED;

- (NSImage*)pc_copyAsBitmapWithSize:(NSSize)size usingInterpolation:(NSImageInterpolation)interpolation NS_RETURNS_RETAINED;
- (NSImage*)pc_copyAsBitmapWithSize:(NSSize)size NS_RETURNS_RETAINED;
- (NSImage*)pc_copyAsBitmap NS_RETURNS_RETAINED;
- (BOOL)pc_isPDF;

- (NSImage*)pc_imageByAdjustingSaturation:(CGFloat)saturation;
- (NSImage*)pc_imageByAdjustingBrightness:(CGFloat)brightness;

- (NSData *)pc_representationUsingType:(NSBitmapImageFileType)storageType;

- (NSImageRep*)pc_repBestMatchingSize:(NSSize)repSize;

- (NSImage *)pc_imageWithNormalizedDPI;

- (NSSize)pc_pixelSize;

- (void)pc_drawFlippedInRect:(NSRect)dstRect fromRect:(NSRect)srcRect operation:(NSCompositingOperation)op fraction:(CGFloat)delta;
- (void)pc_drawFlippedInRect:(NSRect)dstRect;

- (void)pc_drawFlippedInRect:(NSRect)rect inView:(NSView*)aView operation:(NSCompositingOperation)op fraction:(CGFloat)delta;
- (void)pc_drawFlippedInRect:(NSRect)rect inView:(NSView*)aView;

- (void)pc_drawFlippedAtPoint:(NSPoint)dstPoint fromRect:(NSRect)srcRect operation:(NSCompositingOperation)op fraction:(CGFloat)delta;

- (void)pc_drawFlippedHorizontallyInRect:(NSRect)dstRect fromRect:(NSRect)srcRect operation:(NSCompositingOperation)op fraction:(CGFloat)delta;
- (void)pc_drawFlippedHorizontallyInRect:(NSRect)dstRect;

- (NSImage*)pc_imageByTintingWithColor:(NSColor*)aColor;

- (NSImage*)pc_imageWithAlpha:(CGFloat)alpha;

- (NSImage*)pc_compositeImageCentered:(NSImage*)badge;
- (NSImage*)pc_resizeUsingNinePartsToSize:(NSSize)newSize;

- (NSImage*)pc_grayscale;

- (BOOL)pc_writePNGToFile:(NSString*)path;

@end
