//
//  PCFileSystemWatcher.h
//
//  Created by Ian Cely on 1/27/09.
//  Copyright 2009 Panic Inc.. All rights reserved.
//
//	NOTE: If you archive this object it will remember the lastEventID and (when
//	unarchived) will report all events since being archived.

#import <Foundation/Foundation.h>

@class PCFileSystemWatcher;

@protocol PCFileSystemWatcherDelegate

@required
- (void)watcher:(PCFileSystemWatcher*)aWatcher didRecieveChanges:(NSArray*)someChanges;

@optional
- (void)watcher:(PCFileSystemWatcher*)aWatcher rootDidMoveToPath:(NSString*)aNewPath;

@end


@interface PCFileSystemWatcher : NSObject <NSCoding>
{
	NSString* iRootPath;
	NSString* iRootPathResolved;
	FSEventStreamEventId iLastEventID;
	FSEventStreamRef iEventStream;
	CFTimeInterval iLatency;
	id <PCFileSystemWatcherDelegate> iDelegate;
}

- (id)initWithRootPath:(NSString*)rootPath;
- (id)initWithRootPath:(NSString*)rootPath lastEventID:(FSEventStreamEventId)lastEventID;

- (BOOL)start;
- (BOOL)startWithFlags:(FSEventStreamCreateFlags)flags;
- (void)stop;
- (BOOL)isWatchingEvents;

@property (readwrite, assign) id <PCFileSystemWatcherDelegate> delegate;
@property (readonly) FSEventStreamEventId lastEventID;
@property (readonly) NSString* rootPath;
@property (assign) CFTimeInterval latency;

@end


@interface PCFileSystemChange : NSObject
{
	NSString* iPath;
	FSEventStreamEventFlags iFlags;
	FSEventStreamEventId iEventID;
}

- (id)initWithPath:(NSString*)path eventID:(FSEventStreamEventId)eventID flags:(FSEventStreamEventFlags)flags;

@property (readonly) NSString* path;
@property (readonly) BOOL scanSubpaths;
@property (assign) FSEventStreamEventId eventID; // should be treated as readonly, unless you know what you're doing
@property (readonly) FSEventStreamEventFlags flags;

@end
