/*
 *  PCIconTextFieldCell.h
 *
 *  Requires Mac OS X 10.5 or higher and NSImage-Additions category
 *
 *	Provides an icon cell that can show up to two icons in a text cell
 *
 *	-------------------------------------------------------------------
 *
 *
 */

#import <Cocoa/Cocoa.h>

typedef enum
{
	PCVerticalTextAlignmentNatural = 0,		// use NSCell default, which is top aligned
	PCVerticalTextAlignmentTop,				// aligned to the top
    PCVerticalTextAlignmentBottom,			// aligned to the bottom
    PCVerticalTextAlignmentCenter    		// centered
} PCVerticalTextAlignment;

@class PCFieldEditor;

@interface PCIconTextFieldCell : NSTextFieldCell
{
	BOOL iHighlightsText;
    BOOL iHighlightsInactiveText;
	BOOL iDrawsHighlightedTextInBold;
	NSDictionary* iHighlightedTextAttributes;
	NSImage* iImage;
	IconRef iIconRef;
	NSSize iImageSize;
	CGFloat iBaselineOffset;
	PCVerticalTextAlignment iVerticalTextAlignment;
	BOOL iControlViewIsTableView;
	BOOL iSelectsExtensionWhenEditing;
	BOOL iUsesTitleRectForSelection;
	NSCell* iAccessoryCell;
	NSSize iAccessorySize;
    BOOL    iDrawsAccessoryDivider;
	NSColor*    iAccessoryDividerColor;
    NSRectEdge  iAccessoryCellEdge;
    NSGradient* iLabelGradient;
	PCFieldEditor* _fieldEditor; // custom field editor, allows customization of font color in the editor (AppKit has issues)
	NSCell *_imageCell;
}

@property (nonatomic) BOOL highlightsText;
@property (assign) BOOL highlightsInactiveText;
@property (nonatomic) BOOL drawsHighlightedTextInBold;
@property (nonatomic, retain) NSImage* image;
@property NSSize imageSize;
@property (assign) PCVerticalTextAlignment verticalTextAlignment;
@property BOOL selectsExtensionWhenEditing;
@property BOOL usesTitleRectForSelection;
@property (copy) NSCell* accessoryCell;
@property (assign) CGFloat baselineOffset;
@property (nonatomic, assign) BOOL drawsAccessoryDivider;
@property (retain) NSColor* accessoryDividerColor;
@property (nonatomic, assign) NSRectEdge accessoryCellEdge;

- (void)calculateAccessorySize;
- (NSSize)accessoryCellSize;

- (void)setAccessoryImage:(NSImage*)image;
- (void)setAccessoryAction:(SEL)selector;
- (void)setAccessoryTarget:(id)target;

- (void)setIconRef:(IconRef)aRef;
- (void)setLabelColor:(NSColor*)labelColor;

- (NSRect)accessoryRectForBounds:(NSRect)cellFrame;
- (NSRect)imageRectForBounds:(NSRect)cellFrame;
- (NSRect)titleRectForBounds:(NSRect)theRect;

- (void)drawAccessoryDividerWithFrame:(NSRect)frame inView:(NSView*)controlView;
- (void)drawImage:(NSImage*)image withFrame:(NSRect)frame inView:(NSView*)controlView;
- (void)drawIconRef:(IconRef)aRef withFrame:(NSRect)frame inView:(NSView*)controlView;
- (NSRect)dropFrameInRect:(NSRect)aRect;
- (NSRect)fieldEditorFrameForFrame:(NSRect)cellFrame;
- (void)updateFieldEditorSize;

- (NSAttributedString*)highlightedAttributedStringValue;

@end

@interface NSTextFieldCell (FocusRing)

- (NSRect)_focusRingFrameForFrame:(NSRect)frame cellFrame:(NSRect)cellFrame;

@end


@interface PCFieldEditor : NSTextView
{
	BOOL _allowsTypingAttributesChange;
}

@property (assign) BOOL allowsTypingAttributesChange;
@end