#import <Cocoa/Cocoa.h>
#import "Protocols.h"

//#define kColorPathControlHeight 24.0

@protocol PCPathControlDelegate;

@protocol PCPathControlProtocol
- (NSPathComponentCell*)clickedPathComponentCell;
- (NSUInteger)indexOfClickedPathComponentCell;
- (NSArray*)pathComponentCells;
@end


@interface PCPathControl : NSPathControl <PCPathControlProtocol>
{
	BOOL	iShowsStar;
	NSImage *iCustomStarImage;
	NSString *iCustomStarTitle;
	
	SEL		iMenuAction;
	BOOL	iSpringOpenEnabled;
	BOOL 	iFocusLastPathCell;
	NSUInteger iFocusCellIndex; // the cell to draw blue to indicate focus - NSNotFound is none
	BOOL	iDrawsInactive; // defaults to NO
	NSTimer	*iSpringTimer;
	BOOL	iDrawsEndCap;
	BOOL	iCanClickLastComponentCell;
	BOOL	iClickingLastComponentCell;
	BOOL	iPullsDown;
	
	NSString *iTruncatedPathPrefix;
	NSObject <PCViewDraggingDelegateProtocol> * iDraggingDelegate;
}

@property (nonatomic, assign, readwrite) NSObject *draggingDelegate;
@property (nonatomic, assign) BOOL showsStar;
@property (nonatomic, assign) SEL menuAction;
@property (nonatomic, assign) BOOL springOpenEnabled;
@property (nonatomic, assign) BOOL focusLastPathCell;
@property (nonatomic, assign) NSUInteger focusCellIndex;
@property (nonatomic, assign) BOOL drawsEndCap;
@property (nonatomic, assign) BOOL canClickLastComponentCell;
@property (nonatomic, copy) NSImage *customStarImage;
@property (nonatomic, copy) NSString *customStarTitle;
@property (nonatomic, assign) BOOL pullsDown;
@property (nonatomic, assign) BOOL drawsInactive;

- (void)setPath:(NSString*)path;
- (void)setPath:(NSString*)path lastComponentIcon:(NSImage*)image;

- (NSString*)clickedPath;
- (NSUInteger)indexOfClickedPathComponentCell;

- (void)controlTintDidChange:(NSNotification*)notification;

- (id <PCPathControlDelegate>)delegate;

@end


@interface PCPathCell : NSPathCell
{
	NSColor *_bezelColor;
	NSGradient *_highlightGradient;
	NSGradient *_inactiveHighlightGradient;
	BOOL _appearanceTintHighlight;
	NSColor *_chevronColor;
}

@property (retain) NSColor *chevronColor;
@property (nonatomic, retain) NSColor *bezelColor;
@property (nonatomic, retain) NSGradient *highlightGradient;

- (void)setHighlightColor:(NSColor*)color; // sets the highlight gradient by applying the proper color adjustments

+ (Class)pathComponentCellClass;
- (void)drawBackgroundWithFrame:(NSRect)cellFrame inView:(NSView*)view;

@end


@interface PCPathComponentCell : NSPathComponentCell
{
	BOOL iDrawHighlighted;

@private
	NSImageCell *_imageCell;
}

// bridge methods to PCPathCell properties
- (NSGradient*)highlightGradient;

// for subclasses
- (CGFloat)componentOverlapAmount;
- (NSDictionary*)componentTextAttributes;
- (NSSize)popupMenuArrowSize;
//+ (NSColor*)bezelColor; // needed for coda web preview controls
- (void)drawHighlightedBackgroundInRect:(NSRect)rect inView:(NSView*)controlView;
- (void)drawImage:(NSImage*)image withFrame:(NSRect)rect inView:(NSView*)controlView;
- (void)drawEndCapWithFrame:(NSRect)cellFrame highlighted:(BOOL)highlighted inView:(NSView*)controlView;
- (void)drawComponentLeftEdgeInRect:(NSRect)rect highlighted:(BOOL)highlighted inView:(NSView*)controlView;
- (void)drawComponentRightEdgeInRect:(NSRect)rect highlighted:(BOOL)highlighted inView:(NSView*)controlView;
- (void)drawPopupMenuArrowInRect:(NSRect)rect higlighted:(BOOL)highlighted inView:(NSView*)controlView;
//

- (BOOL)isFirstComponent;
- (BOOL)isLastComponent;

//- (void)drawEndCapWithFrame:(NSRect)cellFrame inView:(NSView*)controlView;
- (BOOL)drawHighlighted;

- (CGFloat)minWidthForArrow;

@end


@interface NSEvent (ModifyLocation)

- (NSEvent*)eventWithMouseLocation:(NSPoint)point;

@end


@protocol PCPathControlDelegate <NSPathControlDelegate>

@optional
- (void)pathControl:(PCPathControl*)control springOpenComponentAtIndex:(NSInteger)index;
- (NSMenuItem*)pathControl:(PCPathControl*)control willPopUpComponentMenu:(NSMenu*)menu;
- (NSMenu*)pathControl:(PCPathControl*)control menuForComponentAtIndex:(NSInteger)index;

@end
